#ifndef _MUXSENTK_H
#define _MUXSENTK_H

/************************************************************************
 * 			MEKATRONIX Copyright 1998 		        		*
 * Title        muxsentk.h                                              *
 * Programmer   Keith L. Doty                                           *
 * Date         July 16, 1998                                           *
 * Version      1                                                       *
 *                                                                      *
 * Description										*
 *	This file contains functions to read the TALRIK sensors.          *
 ************************************************************************/


/**************************** Includes **********************************/

#include <hc11.h>
#include <mil.h>
#include <analog.h>

/************************************************************************/


/**************************** Constants *********************************/

#define NIRDT  14          /* Number of multiplexed IR detectors */
#define NCDS   6          /* Number of multiplexed CDS sensors */
#define NXA    6          /* Number of multiplexed eXtra analog sensors */

#define SEL_field 0x1f    /* Ones specify SEL field bit positions */

/*Multiplexer-Motor Direction Register MMR*/
#define MMR   *(unsigned char *)(0xffb8)

/* Define the MMR_SEL field hex values which multiplexes the sensor
   input into its assigned A-to-D channel. 
*/

/*Analog channel on PE0 from here to end of IRD?_SEL #defines */

#define	ECDSR_SEL	0x0a
#define	ECDSM_SEL	0x0b
#define	ECDSL_SEL	0x0c
#define	NCDSR_SEL	0x0d
#define	NCDSM_SEL	0x0e
#define	NCDSL_SEL	0x0f

#define	Charge_Volts_SEL	0x10  /*Not an MRSX01 connector*/
#define	Battery_Volts_SEL	0x11   /*Not an MRSX01 connector*/


#define	IRDR_SEL	0x12
#define	IRDBR_SEL	0x13
#define	IRDBMR_SEL	0x14
#define	IRDBML_SEL	0x15
#define	IRDBL_SEL	0x16
#define	IRDL_SEL	0x17
#define	IRDLW_SEL	0x08
#define	IRDRW_SEL	0x09

#define	IR3clk_SEL	0x12
#define	IR4clk_SEL	0x13
#define	IRD5clk_SEL	0x14
#define	IR7clk_SEL	0x15
#define	IR8clk_SEL	0x16
#define	IR9clk_SEL	0x17

/*Analog Channel PE1 from here down to Analog6*/

#define	R_Bump_SEL	0x10
#define	F_Bump_SEL	0x11

/*Xanalog refers to the ANALOG connector on the MRSXO1*/
#define	Analog1_SEL	0x12
#define	Analog2_SEL	0x13
#define	Analog3_SEL	0x14
#define	Analog4_SEL	0x15
#define	Analog5_SEL	0x16
#define	Analog6_SEL	0x17


/* TALRIK Users Manual sensor names as indicies of IRDT[]. The offset between array
   IRDT[i-1] and its corresponding physical connector name IRDTi is due to zero based
   indexing in the C language.
*/
			 /*IR Detector on the */
#define IRDL 	11	/*Left IRDT12*/
#define IRDFL 	1  	/*Front Left IRDT2*/
#define IRDFML 	2 	/*Front Middle Left IRDT3*/
#define IRDFM 	3 	/*Front Middle IRDT4*/
#define IRDFMR 	4 	/*Front Middle Right IRDT5*/
#define IRDFR 	0 	/*Front Right IRDT1*/
#define IRDR 	6 	/* Right IRDT7*/
#define IRDBL 	10 	/*Back Left IRDT11*/
#define IRDBML 	9		/*Back Middle Left IRDT10*/
#define IRDBM 	5		/*Back Middle IRDT6*/
#define IRDBMR 	8		/*Back Middle Right IRDT9*/
#define IRDBR 	7		/*Back Right IRDT8*/
#define IRDLW 	12	/*Back Left Wheel (Optional) IRDT13*/
#define IRDRW 	13	/*Back Right Wheel (Optional)IRDT14*/

/* TALRIK sensor clock position indicies into the IRDT array*/
			
#define IR1clk 	4   /* IR sensor at one o'clock is IRDT[IR1clk]=IRDT[4], etc*/
#define IR2clk 	0  	
#define IR3clk 	6 	  
#define IR4clk	7 	  
#define IR5clk 	8 	
#define IR6clk 	5 	
#define IR7clk 	9 	
#define IR8clk 	10 	
#define IR9clk 	11	
#define IR10clk 1		
#define IR11clk 2		
#define IR12clk 3  /* IR sensor at Twelve o'clock is IRDT[IR12clk]=IRDT[3] */


			 /*Nose CDS cells*/
#define NCDSL CDS[5] 		/*Left*/
#define NCDSM CDS[4]		/*Middle*/
#define NCDSR CDS[3]		/*Right*/

			 /*Eye CDS cells*/
#define ECDSL CDS[2] 		/*Left*/
#define ECDSM CDS[1] 		/*Middle*/
#define ECDSR CDS[0] 		/*Right*/

/* 
  Caution! Mekatronix reserves the following for future sensor assignments
  which may not be compatible to user sensor assignments.

*/

#define Analog1 Xanalog[0]
#define Analog2 Xanalog[1]
#define Analog3 Xanalog[2]
#define Analog4 Xanalog[3]
#define Analog5 Xanalog[4]
#define Analog6 Xanalog[5]

/************************************************************************/


/*************************** Prototypes *********************************/

void MMR_bit_clear(int);	/* Clear specified 1-bits in MMR.SEL */
void MMR_bit_set(int);		/* Set specified 1-bits in MMR.SEL */
void mux_sensor(int);		/* Load specified field into MMR.SEL */

void read_IR(void);		/*Reads all the TALRIK IR sensor inputs*/
void read_CDS(void);		/*Reads all the TALRIK CDS sensor inputs*/
void read_Xanalog(void);	/*Reads all the TALRIK sensors connected
				  the 6-pin Analog port of the MRSX01 board.	
				*/

unsigned int rear_bumper(void);	        /*Returns rear bumper value*/
unsigned int front_bumper(void);	/*Returns front bumper value*/
unsigned int charge_volts(void);	/*Returns the charging voltage level*/
unsigned int battery_level(void);	/*Returns the battery voltage level*/

/************************************************************************/


/***************************** Globals **********************************/

extern unsigned int IRDT[NIRDT], CDS[NCDS], Xanalog[NXA];

/* Buffer memory of the MMR at(0xffb8). Mirrors contents of write-only MMR */
extern char MMR_mirror; 

/************************************************************************/

#endif

