
#ifndef _SERIALTK_H
#define _SERIALTK_H

/**********************************************************************
 * 			MEKATRONIX Copyright 1998 		      *
 *  Title:       serialtk.h    		                              *
 *  Programmer:  Keith L. Doty                                        *
 *  Date:        March 13, 1998                                       *
 *  Version:     2.1                                                  *
 *  Description:                                                      *
 *    Serial Port I/O Routines for ICC11 on the 68HC11                *
 *    init_serial must be called in order to use any of the           *
 *    functions.  Enables ICC11 programs to use the serial            *
 *    port without Buffalo Monitor.                                   *
 *                                                                    *
 *    Include this code in programs that need to use the serial port  *
 *    for I/O.                                                        *
 *                                                                    *
 *    Serial Protocol of this program:                                *
 *      baud=9600, 8 data bits, 1 stop bit, no parity, no flow        *
 *      control.                                                      *
 *                                                                    *
 *    Example:                                                        *
 *      Configure Hyperterm on Win95:                                 *
 *      Direct to COM1, 9600 baud, 8 bits, no parity, 1 stop bit, no  *
 *      flow control.                                                 *
 *                                                                    *
 *   Requires hc11.h and mil.h to work                                *
 *                                                                    *
 *   Version History                                                  *
 *     V1 Written by Reid Harrison                                    *
 *     V2 Minor Modifications by Scott Jantz and Keith L.Doty         *
 *     V2.1 Standardized by Keith L. Doty added read_int().           *
 **********************************************************************/


/*************************** Includes ********************************/
#include <hc11.h>
#include <mil.h>
/************************ End of Includes ****************************/

/***************************** Prototypes ****************************/

void init_serial(void); /* Set up the SCI port  */
int get_char(void); /* Read (receive) a character from the SCI port.*/
void put_char(int); /* Write (transmit) a character to the SCI port.*/
void write(char *string); /* Write (transmit) a character string. */
void put_int(int);   /* Write (transmit) an integer to the SCI port. */
void write_int(int);
/* 
 * Write (transmit) an integer to the SCI port prefixed by a space and
 * followed by a newline (carriage_return, line_feed).
 */
int read_int(); 
/* 
 * Read(receive) an integer from the SCI port
 * followed by a carriage_return and a line_feed.
 */


/************************ End of Prototypes **************************/

#endif
