/************************************************************************
 * 			MEKATRONIX Copyright 1998 			*
 * Title        analog.c                                      	        *
 * Programmer   Keith L. Doty                                           *
 * Date         July 8, 1998      	                                *
 * Version      1.1                                                     *
 *                                                                      *
 * Description								*
 *   Routines to power up the analog port and to read the 8 channels.   *
 *									*
 ************************************************************************/

/**************************** Includes **********************************/
#include <hc11.h>
#include <mil.h>
/************************************************************************/

/**************************** Constants *********************************/

#define NADC 8            /* Number of Analog-to-Digital channels */
#define AD_XTIME 300	/* 150 microseconds allowed to execute analog() and
			   TOC5_isr "auto-AD-conversion" of 4 channels
 			*/
/************************************************************************/

/***************************** Globals **********************************/

unsigned int AtoD[NADC];

/* AtoD[NADC] is an AD data buffer that holds the AD conversions taking
   place every 1msec by TOC5_isr
 */

/************************************************************************/



/*************************** Prototypes *********************************/

void init_analog(void);   /* Power up A/D */
int analog(int);   	  /* Read analog channel 0<= int <= 7 */

/************************************************************************/



void init_analog(void)
/* This routine must be executed before the function analog is called.  */

{
int i;

  SET_BIT(OPTION,0x80);            /* Power up A/D */
  for(i=0; i<8; i++) AtoD[i] = 0;  /* Clear AD data buffer */
                  
}

/**********************End of init_analog ******************************/


int analog(int port)
/************************************************************************
 * Function: Takes one reading from the analog port and returns the	*
 *	     value read. This function will not disrupt the automatic	*
 *           AD conversion process implemented in TOC5_isr.		*
 *                                                                      *
 * 	     150 microseconds alloted this routine guantees enough time	*
 *	     for a single 16 microsecond "instant" AD conversion as well*
 *	     leaving enough time for the automated AD sampling to 	*
 *	     recover before the next TOC5 interrupt.			*			*
 *                                                                      *
 * Returns:  Analog value read from A/D PORTE                           *
 *                                                                      *
 * Inputs                                                               *
 *   Parameters: None                                                   *
 *   Globals:    None                                                   *
 *   Registers:  PORTE                                                  *
 * Outputs                                                              *
 *   Parameters: None                                                   *
 *   Globals:    None							*
 *   Registers:	 None				                        *
 * Functions called: None                                               *
 *                                                                      *
 * Usage: Pemits instantaneously reading a sensor asynchronously with	*
 * 	  the TOC5_isr which takes two milliseconds to update a sensor	*
 *        datum.							*
 ************************************************************************/
{
  ADCTL=port;	/* Address the selected channel */
      
/* The NOP codes give the A/D time to convert the input and save in ADR1 */

  asm("NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n");
  asm("NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n" "NOP\n");

   return ADR1;		/* Return analog value */
}

/**********************End of analog ******************************/
