/************************************************************************
 * 			MEKATRONIX Copyright 1998 		        *
 * Title        avoid2tk.c                                               *
 * Programmer	Keith L. Doty	        				*
 * Date         July 27, 1998                                           *
 * Version	1			                		*
 *								        *
 * Description								*
 *    A very simple collision avoidance program. TALRIK will read 	*
 *    the five front IR detectors, and turn away from any obstacles in 	*
 *    its path. Also, if something hits the front bumper, it will turn  *
 *    its head in the direction of the bump, back up, turn, and go on.	*
 *			                                                *     					*
 ************************************************************************/
 
/**************************** Includes **********************************/
#include <tkbase.h>
/************************ End of includes *******************************/

/**************************** Constants *********************************/
#define FORWARD 100
#define REVERSE -100
#define HFORW 50
#define HREV -50
#define IR_THRESHOLD 117
#define BUMPER_FUZZY_ZERO 12 /* Noise immunity for bumper readings */

#define HEAD_SERVO 0 /*This is Servo_01 connector on MRSX011 board*/

/*IR emitter output port driver, the output latch at address 0xffb9 */
#define IRE_OUT   *(unsigned char *)(0xffb9) 

/*Constant for driving all the 40KHz modulated IR emitters on when loaded into IRE_OUT */
#define IRE_ALL_ON 0xff 

/*Constant for turning all the 40KHz modulated IR emitters off when loaded into IRE_OUT */
#define IRE_ALL_OFF 0x00

/************************ End of Constants ****************************/

/*************************** Prototypes *********************************/
void turn(void);
void move_head(int);
/************************ End of Prototypes *****************************/

/***************************** Globals **********************************/

/************************** End of Globals ******************************/


void main(void)
/****************************** Main ***********************************/
{
unsigned int IR_delta[NIRDT], IR_Threshold[NIRDT];
int i, fb, rspeed, lspeed, delta_rspeed, delta_lspeed;

  init_analog();
  init_motortk();
  init_clocktk();
  init_servos();
  init_serial();

  lspeed = rspeed = FORWARD; /*Initial movement of TALRIK is forward*/

  IRE_OUT = IRE_ALL_ON;    /* Turns on all the 40KHz modulated IR emitters */
  wait(300);		   /* Allow IR detectors to reach final values */

/*Start TALRIK moving forward when back bumper is pressed*/
  while(rear_bumper()<BUMPER_FUZZY_ZERO);
   
  motortk(RIGHT_MOTOR, rspeed); 
  motortk(LEFT_MOTOR, lspeed);


  while(1)
  {

/* The following block will read the IR detectors and decide
   whether TALRIK needs to turn to avoid any obstacles
*/
    read_IR();

  if((IRDT[IR10clk] > IR_THRESHOLD ) || (IRDT[IR11clk] > IR_THRESHOLD ) ||
     (IRDT[IR12clk] > IR_THRESHOLD ) || (IRDT[IR1clk] > IR_THRESHOLD )  || 
     (IRDT[IR2clk] > IR_THRESHOLD ))
    {
      if(IRDT[IR2clk] > IRDT[IR10clk]) 
      /* Start turning when something in front and keep turning until nothing
        is in front */
        {
    	 lspeed = HREV;
    	 rspeed = HFORW;
    	}
      else
    	{
    	  lspeed = HFORW;
    	  rspeed = HREV;
	}

      motortk(RIGHT_MOTOR, rspeed); 
      motortk(LEFT_MOTOR, lspeed);

      while((IRDT[IR10clk] > IR_THRESHOLD ) || (IRDT[IR11clk] > IR_THRESHOLD ) ||
            (IRDT[IR12clk] > IR_THRESHOLD ) ||  (IRDT[IR1clk] > IR_THRESHOLD ) ||
            (IRDT[IR2clk] > IR_THRESHOLD ))
    		read_IR();			

    }
  else
    {
      lspeed = 100;		
      rspeed = 100;
    }
 
    motortk(RIGHT_MOTOR, rspeed); 
    motortk(LEFT_MOTOR, lspeed);

/* This "if" statement checks the front bumper. If the bumper is pressed,
   TALRIK will back up, and turn. 
*/

    if((fb=front_bumper())>BUMPER_FUZZY_ZERO)
    {
      move_head(fb);
      motortk(LEFT_MOTOR, HREV);
      motortk(RIGHT_MOTOR, HREV);
      wait(350);
      turn();
    }

    if(rear_bumper()>BUMPER_FUZZY_ZERO)
    {
      motortk(LEFT_MOTOR, HFORW);
      motortk(RIGHT_MOTOR, HFORW);
      wait(350);
      turn();
    }

    wait(35);
  }    
}
/**************************** End of Main ******************************/

void turn()
/************************************************************************
 * Function:  Will turn in a random direction for a random amount of    *
 * time                                                                 *
 * Returns:  None                                                       *
 *                                                                      *
 * Inputs                                                               *
 *   Parameters: None                                                   *
 *   Globals:    None                                                   *
 *   Registers:  TCNT                                                   *
 * Outputs                                                              *
 *   Parameters: None                                                   *
 *   Globals:    None                                                   *
 *   Registers:  None                                                   *
 * Functions called: None                                               *
 * Notes:                                                               *
 ************************************************************************/
{
 int i;
 unsigned rand;

 rand = TCNT;

 if (rand & 0x0001)
 {
   motortk(RIGHT_MOTOR, FORWARD);
   motortk(LEFT_MOTOR, REVERSE);
 }
 else
 {
   motortk(RIGHT_MOTOR, REVERSE);
   motortk(LEFT_MOTOR, FORWARD);
 }
 /*for (i = 0; i < rand; i++);*/
 i=(rand % 1024) + 35;
 wait(i);

}
/**************************end turn**************************************/


void move_head(int fb)
/************************************************************************
 * Function:  Will turn TALRIK head to face direction of bump contact.  *
 * time                                                                 *
 * Returns:  None                                                       *
 *                                                                      *
 * Inputs                                                               *
 *   Parameters: fb front bumper value.                                 *
 *   Globals:    None                                                   *
 *   Registers:  None                                                   *
 * Outputs                                                              *
 *   Parameters: None                                                   *
 *   Globals:    None                                                   *
 *   Registers:  None                                                   *
 * Functions called: None                                               *
 * Notes:                                                               *
 ************************************************************************/
{
    switch (fb)/*Select an IR detector on TALRIK according to clock position */
       {
         case 127: servo(HEAD_SERVO,1400);  break;
         case 151: servo(HEAD_SERVO,1725);  break;
         case 81:  servo(HEAD_SERVO,2050);  break;
         case 103: servo(HEAD_SERVO,2375);  break;
         case 45:  servo(HEAD_SERVO,2700);  break;
         case 61:  servo(HEAD_SERVO,3025);  break;
         case 23:  servo(HEAD_SERVO,3350);  break;
         case 36:  servo(HEAD_SERVO,3675);  break;
         case 16:  servo(HEAD_SERVO,4000);  break;
       }
 
}
/**************************end move_head**************************************/
