/************************************************************************
 * Title        taltst.c                                	                
 * Programmer	Keith L. Doty	        				
 * Date         March, 1999      	                                
 * Version	1			                		
 *								        
 * Description
 *   This program allows you to test all of TALRIK's basic features:
	IR Detectors
        CdS photoresistors
        Motors
        Servos
 *
 *   Select the appropriate test from the startup menu. When finished, press
 *   reset on TALRIK and select the next test.
 *									
 * Use Hyperterm with the following settings:                           
 *   									
 *      COM1, 9600 Baud, 8 bits, No Parity, 1 Stop bit, No Flow         
 *      of Control, VT100 Terminal, WrapLines.				
 *									
 *Usage: Verify functionality of TALRIK's sensors.
 ************************************************************************/
 
/**************************** Includes **********************************/

#include <tkbase.h>
#include <stdio.h>

/************************ End of includes *******************************/

void sensors_tst(void);
void servo_tst(void);
void motor_tst(void);


void main(void)
/****************************** Main ***********************************/
{
  unsigned int bl, cv, fb, rb, run_test;
  char clear[]= "\x1b\x5B\x32\x4A\x04";  /* clear screen */ 
  char place[]= "\x1b[1;1H";		/* Home cursor */

  init_analog();
  init_motortk();
  init_clocktk();
  init_serial();
  init_servos();

  printf("%s", clear);  /*clear screen*/
  printf("%s", place);  /*home cursor*/

  printf("\tTitle\t\ttaltst.c\n"
  "\tProgrammer\tKeith L. Doty\n"
  "\tDate\t\tMarch 22, 1998\n"
  "\tVersion\t\t1\n\n");

  printf("Select one of the following TALRIK test procedures\n"
         "   1. Test TALRIK Sensors \n"
	     "   2. Test TALRIK Servos\n"
	     "   3. Test TALRIK Motors  (CAREFUL!!! The robot will start moving immediately!)\n\n");

  run_test= read_int();

    switch (run_test)/*Select a test procedure */
       {
         case 1: sensors_tst(); break;
         case 2: servo_tst(); break;
         case 3: motor_tst(); break;
       }

  

}
/**************************** End of Main ******************************/


/*************************** Constants **********************************/

/*IR emitter output port driver, the output latch at address 0xffb9 */
#define IRE_OUT   *(unsigned char *)(0xffb9) 

/*Constant for driving all the 40KHz modulated IR emitters on when loaded into IRE_OUT */
#define IRE_ALL_ON 0xff 

/*Constant for turning all the 40KHz modulated IR emitters off when loaded into IRE_OUT */
#define IRE_ALL_OFF 0x00

/************************ End of Constants *****************************/


void sensors_tst(void)
/**************************** sensor_dsply *****************************
 * Description
 * Displays TALRIK's sensor inputs, 12 IR detectors, 6 Photoresistors,
 * front bumper, rear bumper, charge level, battery level.
 *									
 *Usage: Verify functionality of TALRIK's sensors.
 ************************************************************************/
{
  unsigned int bl, cv, fb, rb;
  char clear[]= "\x1b\x5B\x32\x4A\x04";  /* clear screen */ 
  char place[]= "\x1b[1;1H";		/* Home cursor */

  IRE_OUT = IRE_ALL_ON;    /* Turns on all the 40KHz modulated IR emitters */

  printf("%s", clear);  /*clear screen*/
  printf("%s", place);  /*home cursor*/

/* Template for the TALRIK sensor display pattern */
  printf("\t\t\tIRDFM\n\n");
  printf("\t\tIRDFML\t\tIRDFMR\n\n");
  printf("\t\t\tNCFDM\n");
  printf("\tIRDFL\tNCDSL\t%u\tNCDSR\tIRDFR\n\n\n",CDS[4]);
  printf("\t\tECDSL\tECDSM\tECDSR\n");
  printf("    IRDL\t\t\t\t    IRDR\tTALRIK SENSOR INPUTS\n\n\n\n");
  printf("\tIRDBL\t\t\t\tIRDBR\n\n\n");
  printf("\t\tIRDBML\t\tIRDBMR\n\n");
  printf("\t\t\tIRDBM\n\n\n");
  printf("\tF_BUMP\tR_BUMP\t\tCHARGE\tBATTERY\n");
  
  printf("\n\n\n\nPress TALRIK Reset Switch to select another test.");


while(1)  /* Update the sensor fields indefinitely */
  {
  
  read_IR();     /* Read all 14 IR sensors */
  read_CDS();    /* Read all 6 CDS photoresistor voltage dividers */

  bl = battery_level();	/*Returns the battery voltage level*/
  cv = charge_volts();	/*Returns the charging voltage level*/
  fb = front_bumper();	/*Returns front bumper value*/
  rb = rear_bumper();	/*Returns rear bumper value*/  


   printf("\x1b[2;25H   \b\b\b%u", IRDT[3]);  /*select IRDFM*/

   printf("\x1b[4;17H   \b\b\b%u\x1b[4;33H   \b\b\b%u", IRDT[2],IRDT[4]);
   printf("\x1b[6;25H   \b\b\b%u", CDS[4]);
   printf("\x1b[7;9H   \b\b\b%u\x1b[7;17H   \b\b\b%u", IRDT[2], CDS[5]);
   printf("\x1b[7;33H   \b\b\b%u\x1b[7;41H   \b\b\b%u", CDS[3], IRDT[0]);
   printf("\x1b[10;17H   \b\b\b%u\x1b[10;25H   \b\b\b%u",CDS[2],CDS[1]);
   printf("\x1b[10;33H   \b\b\b%u",CDS[0]);
   printf("\x1b[11;5H   \b\b\b%u\x1b[11;45H   \b\b\b%u", IRDT[11], IRDT[6]);
   printf("\x1b[15;9H   \b\b\b%u\x1b[15;41H   \b\b\b%u", IRDT[10], IRDT[7]);
   printf("\x1b[18;17H   \b\b\b%u\x1b[18;33H   \b\b\b%u", IRDT[9], IRDT[8]);
   printf("\x1b[20;25H   \b\b\b%u", IRDT[5]);
   printf("\x1b[23;9H   \b\b\b%u\x1b[23;17H   \b\b\b%u",fb, rb);
   printf("\x1b[23;33H   \b\b\b%u\x1b[23;41H   \b\b\b%u", cv, bl );


  } /*end while*/
  

}

/**************************** sensors_tst ******************************/


void servo_tst(void)
/**************************** servo_tst *******************************
 *								        
 * Description
 *
 *   Press and hold the rear bumper down and TALRIK's Head servo rotates
 *   in one direction. Press and hold the front bumper down and the Head
 *   rotates in the other direction. The PWM pulse width (1000<PW<5000)
 *   is output to the terminal. By momentarily pressing the bumpers you can
 *   step the PWM pulse width by a fixed number of processor cycle increments
 *   in either direction.
 *									
 ************************************************************************/
{
int i, rb;
unsigned int lpw, upw, servo_step;

/* VT100 clear screen */ 
  char clear[]= "\x1b\x5B\x32\x4A\x04"; 

/* VT100 position cursor at (x,y) = (3,12) command is "\x1b[3;12H"*/
  char place[]= "\x1b[1;1H";	/*Home*/	

  printf("%s", clear);  
  printf("%s", place);  
  
  lpw =1000;
  upw = 5000;
  servo_step = 100;

  printf("The Servo Pulse width = \n\n");
  printf("Press TALRIK Reset Switch to select another test.");


  while(1)
  {
    for( i=lpw; i< upw +1; i += servo_step)
    {
      servo(0,i);
      servo(1,i);
      printf("\x1b[1;24H      ");
      printf("\x1b[1;24H%d", i);
      wait(100);
    }
    for( i=upw; i> lpw - 1; i -=servo_step)
    {
      servo(0,i);
      servo(1,i);
      printf("\x1b[1;24H      ");
      printf("\x1b[1;24H%d", i);
      wait(100);
    }
  }

}
/**************************** servo_tst *******************************/

void motor_tst(void)
/**************************** motor_tst *********************************
 * Description								*
 *   Input two integers to specify the speed and direction of the left  *
 *   and right wheels. The integers must lie between -100 and +100. Any *
 *   non-digit character will terminate the integer, e.g., a blank.     *
 *									*
 *   	      CAREFUL!!! The robot will start moving immediately!	*
 *									*
 *   To input another pair of speeds, press reset to start the program  *
 *   over. 								*
 *									*
 *  Usage: This function allows you to move the robot at any fixed      *
 *         wheel speed ratios to generate either straight or circular	*
 *         motion.  							*
 ************************************************************************/
{
  int i;
/* VT100 clear screen */ 
  char clear[]= "\x1b\x5B\x32\x4A\x04"; 

/* VT100 position cursor at (x,y) = (3,12) command is "\x1b[3;12H"*/
  char place[]= "\x1b[1;1H";	/*Home*/	

  init_motortk();
  init_serial();

  printf("%s", clear);  
  printf("%s", place);

 
  printf("Motor Speed = \n\n");
  printf("Press TALRIK Reset Switch to select another test.");


  while(1)
  {
    for( i=-100; i< 101; i +=10)
    {
      motortk(RIGHT_MOTOR, i); 
      motortk(LEFT_MOTOR, i);
      printf("\x1b[1;14H      ");
      printf("\x1b[1;14H%d", i);
      wait(200);
    }

    for( i=100; i> -101; i -=10)
    {
      motortk(RIGHT_MOTOR, i); 
      motortk(LEFT_MOTOR, i);
      printf("\x1b[1;14H      ");
      printf("\x1b[1;14H%d", i);
      wait(200);
    }
  }

}
/**************************** motor_tst ******************************/



