/************************************************************************
 * Title        xir1tk.c                                	                *
 * Programmer	Keith L. Doty	        				*
 * Date         July 21, 1998      	                                *
 * Version	1			                		*
 *								        *
 * Description								*
 *   This program turns on the IR emitters, modulated at 40KHz, for a   *
 *   user specified time, in msec, called IR_delay. During that time the*
 *   IR detector IRDR charges up to a particular value, is sampled 	*
 *   and displayed. The IR emitters are then turned off. A wait of	*
 *   IR_delay msec passes while the IR detector IRDR discharges. 	* 
 *   The resulting value of the detector after the IR_delay is then	*
 *   displayed again.							*
 *                                                                      *
 *   									*
 *									*
 * Use Hyperterm with the following settings:                           *
 *   									*
 *      COM1, 9600 Baud, 8 bits, No Parity, 1 Stop bit, No Flow         *
 *      of Control, VT100 Terminal, WrapLines.				*
 *									*
 *                                                                      *
 *  Usage: This program allows you to test the IRDR detectorand measure		*
 *         its response time to the nearest millisecond. Try the 	*
 *         following values for IR_delay: 1,10, 50, 100, 200, 250, 275,	*
 *         300, 350, 500, and 1000 msec. Determine the full turn-on and *
 *         full-turn off times of this IR detector. Be sure not to	*
 *         change the environment around TALRIK, otherwise the IR 	*
 *         detector readings will change during your experiments!	*
 * Note: IRDR = IRDT7 is at 3 0'clock on the TALRIK plate (IRDRight) and*
 *       is a multiplexed IR detector input.			 	*
 ************************************************************************/
 
/**************************** Includes **********************************/

#include <tkbase.h>
#include <stdio.h>

/************************ End of includes *******************************/


/*************************** Constants **********************************/

/*IR emitter output port driver, the output latch at address 0xffb9 */
#define IRE_OUT   *(unsigned char *)(0xffb9) 

/*Constant for driving all the 40KHz modulated IR emitters on when loaded into IRE_OUT */
#define IRE_ALL_ON 0xff 

/*Constant for turning all the 40KHz modulated IR emitters off when loaded into IRE_OUT */
#define IRE_ALL_OFF 0x00

/************************ End of Constants ******************************/


void main(void)
/****************************** Main ***********************************/
{
  int i, IR_delay;
  unsigned int temp;
/* VT100 clear screen */ 
  char clear[]= "\x1b\x5B\x32\x4A\x04"; 

/* VT100 position cursor at (x,y) = (3,12) command is "\x1b[3;12H"*/
  char place[]= "\x1b[1;1H";	/*Home*/	

  init_analog();
  init_clocktk();
  init_serial();

  printf("%s", clear);  
  printf("%s", place);
  
  printf("\tTitle\t\txir1tk.c\n"
  "\tProgrammer\tKeith L. Doty\n"
  "\tDate\t\tJuly 28, 1998\n"
  "\tVersion\t\t1\n\n");

/* Initialize MMR_mirror to binary ???10010, Right side IR detector (IRDR)*/
  mux_sensor(IRDR_SEL);

while(1)
  {
  printf("Enter millisecond time delay called IR_delay (1...65,535): ");
  IR_delay = read_int();

  IRE_OUT = IRE_ALL_ON;    /* Turns on all the 40KHz modulated IR emitters */
  wait(IR_delay);    /* Wait IR_delay msec for the IR detectors to respond*/
  
  temp = analog(0); /* saved in temp*/

  IRE_OUT = IRE_ALL_OFF;    /* Turns off all the 40KHz modulated IR emitters */
  wait(IR_delay);    /* Wait IR_delay msec for the IR detectors to discharge*/

  IRDT[IRDR] = analog(0);

/* Display IR values */
  write("IRDR value after IR emitters are 'ON' for IR_delay:  "); write_int(temp);

  write("IRDR value after IR emitters are 'OFF' for IR_delay after 'ON' IR_delay:  ");
  write_int(IRDT[IRDR]);
  printf("\n\n");
  }

}

/**************************** End of Main ******************************/

