/************************************************************************
 * Title        xsensetk.c                                	                
 * Programmer	Keith L. Doty	        				
 * Date         July 24, 1998      	                                
 * Version	1			                		
 *								        
 * Description
 * Displays TALRIK's sensor inputs, 12 IR detectors, 6 Photoresistors,
 * front bumper, rear bumper, charge level, battery level.
 *									
 * Use Hyperterm with the following settings:                           
 *   									
 *      COM1, 9600 Baud, 8 bits, No Parity, 1 Stop bit, No Flow         
 *      of Control, VT100 Terminal, WrapLines.				
 *									
 *Usage: Verify functionality of TALRIK's sensors.
 ************************************************************************/
 
/**************************** Includes **********************************/

#include <tkbase.h>
#include <stdio.h>

/************************ End of includes *******************************/


/*************************** Constants **********************************/

/*IR emitter output port driver, the output latch at address 0xffb9 */
#define IRE_OUT   *(unsigned char *)(0xffb9) 

/*Constant for driving all the 40KHz modulated IR emitters on when loaded into IRE_OUT */
#define IRE_ALL_ON 0xff 

/*Constant for turning all the 40KHz modulated IR emitters off when loaded into IRE_OUT */
#define IRE_ALL_OFF 0x00

/************************ End of Constants ******************************/


void main(void)
/****************************** Main ***********************************/
{
  unsigned int bl, cv, fb, rb;
  char clear[]= "\x1b\x5B\x32\x4A\x04";  /* clear screen */ 
  char place[]= "\x1b[1;1H";		/* Home cursor */


  init_analog();
  init_motortk();
  init_clocktk();
  init_serial();

  IRE_OUT = IRE_ALL_ON;    /* Turns on all the 40KHz modulated IR emitters */

  printf("%s", clear);  /*clear screen*/
  printf("%s", place);  /*home cursor*/

/* Template for the TALRIK sensor display pattern */
  printf("\t\t\tIRDFM\n\n");
  printf("\t\tIRDFML\t\tIRDFMR\n\n");
  printf("\t\t\tNCFDM\n");
  printf("\tIRDFL\tNCDSL\t%u\tNCDSR\tIRDFR\n\n\n",CDS[4]);
  printf("\t\tECDSL\tECDSM\tECDSR\n");
  printf("    IRDL\t\t\t\t    IRDR\tTALRIK SENSOR INPUTS\n\n\n\n");
  printf("\tIRDBL\t\t\t\tIRDBR\n\n\n");
  printf("\t\tIRDBML\t\tIRDBMR\n\n");
  printf("\t\t\tIRDBM\n\n\n");
  printf("\tF_BUMP\tR_BUMP\t\tCHARGE\tBATTERY\n");

while(1)  /* Update the sensor fields indefinitely */
  {
  
  read_IR();     /* Read all 14 IR sensors */
  read_CDS();    /* Read all 6 CDS photoresistor voltage dividers */

  bl = battery_level();	/*Returns the battery voltage level*/
  cv = charge_volts();	/*Returns the charging voltage level*/
  fb = front_bumper();	/*Returns front bumper value*/
  rb = rear_bumper();	/*Returns rear bumper value*/  


   printf("\x1b[2;25H   \b\b\b%u", IRDT[3]);  /*select IRDFM*/

   printf("\x1b[4;17H   \b\b\b%u\x1b[4;33H   \b\b\b%u", IRDT[2],IRDT[4]);
   printf("\x1b[6;25H   \b\b\b%u", CDS[4]);
   printf("\x1b[7;9H   \b\b\b%u\x1b[7;17H   \b\b\b%u", IRDT[2], CDS[5]);
   printf("\x1b[7;33H   \b\b\b%u\x1b[7;41H   \b\b\b%u", CDS[3], IRDT[0]);
   printf("\x1b[10;17H   \b\b\b%u\x1b[10;25H   \b\b\b%u",CDS[2],CDS[1]);
   printf("\x1b[10;33H   \b\b\b%u",CDS[0]);
   printf("\x1b[11;5H   \b\b\b%u\x1b[11;45H   \b\b\b%u", IRDT[11], IRDT[6]);
   printf("\x1b[15;9H   \b\b\b%u\x1b[15;41H   \b\b\b%u", IRDT[10], IRDT[7]);
   printf("\x1b[18;17H   \b\b\b%u\x1b[18;33H   \b\b\b%u", IRDT[9], IRDT[8]);
   printf("\x1b[20;25H   \b\b\b%u", IRDT[5]);
   printf("\x1b[23;9H   \b\b\b%u\x1b[23;17H   \b\b\b%u",fb, rb);
   printf("\x1b[23;33H   \b\b\b%u\x1b[23;41H   \b\b\b%u", cv, bl );


  } /*end while*/
  

}

/**************************** End of Main ******************************/

