/************************************************************************
 * Title        xserv1tk.c                                	                
 * Programmer	Keith L. Doty	        				
 * Date         July 28, 1998      	                                
 * Version	1			                		
 *								        
 * Description
 *
 *   Press and hold the rear bumper down and TALRIK's Head servo rotates
 *   in one direction. Press and hold the front bumper down and the Head
 *   rotates in the other direction. The PWM pulse width (1000<PW<5000)
 *   is output to the terminal. By momentarily pressing the bumpers you can
 *   step the PWM pulse width by a fixed number of processor cycle increments
 *   in either direction.
 
 * NOTE: SOME SERVOS HAVE INVERTED CONTROL AND WILL MOVE IN THE OPPOSITE
         DIRECTION. YOU CAN CORRECT FOR THIS IN THE SOFTWARE.
 *								
 * Use Hyperterm with the following settings:                           
 *   									
 *      COM1, 9600 Baud, 8 bits, No Parity, 1 Stop bit, No Flow         
 *      of Control, VT100 Terminal, WrapLines.				
 *									
 ************************************************************************/
 
/**************************** Includes **********************************/

#include <tkbase.h>
#include <stdio.h>

/************************ End of includes *******************************/


/*************************** Constants **********************************/

#define HEAD_SERVO 0 /*This is Servo_01 connector on MRSX011 board*/
#define BUMPER_FUZZY_ZERO 12 /* Noise immunity for bumper readings */

/************************ End of Constants ******************************/

void main(void)
/****************************** Main ***********************************/
{
int i, rb;
unsigned int lpw, upw, servo_step;

/* VT100 clear screen */ 
  char clear[]= "\x1b\x5B\x32\x4A\x04"; 

/* VT100 position cursor at (x,y) = (3,12) command is "\x1b[3;12H"*/
  char place[]= "\x1b[1;1H";	/*Home*/	

  init_analog();
  init_motortk();
  init_clocktk();
  init_serial();
  init_servos();

  printf("%s", clear);  
  printf("%s", place);  
  
  printf("\tTitle\t\txserv1tk.c\n"
  "\tProgrammer\tKeith L. Doty\n"
  "\tDate\t\tJuly 28, 1998\n"
  "\tVersion\t\t1\n\n");

  printf("Press and hold the rear bumper down and TALRIK's Head servo rotates\n"
         "in one direction. Press and hold the front bumper down and the Head \n"
	 "rotates in the other direction. The PWM pulse width (1000<PW<5000)\n"
	 "is output to the terminal. By momentarily pressing the bumpers you can\n"
         "step the PWM pulse width by a fixed number of processor cycle increments in\n"
         "either direction.\n");

  lpw=0;
  upw = 6000;
  while(lpw <1000 || upw>5000)
   {
    printf("\nEnter Lower Pulse Width Limit (999<lpw<2000) (Spec is 1000): ");
    lpw = read_int();
    printf("\nEnter Upper Pulse Width Limit (2000<upw<5000) (Spec is 5000): ");
    upw = read_int();
   }
   
  printf("\nEnter servo step size: ");
  servo_step = read_int();
  printf("\n\nPress the bumpers at will to move the Head servo\n\n");
  i = lpw;
while(1)
  {
  
/* 
   The AD input generates noise on first two bits when it is frequently
   changed, hence, the test for "0" must be fuzzified. The fuzzy
   zero is chosen to be 12 here to give noise immunity. Since the smallest back
   bumper reading is 23, there will be no confusion between a bump 
   and a fuzzy zero.

*/  
  
  while((rb=rear_bumper())>BUMPER_FUZZY_ZERO) 
   {
     i += servo_step;
     if(i>upw) i = lpw;
     printf("Servo Pulse Width is      \b\b\b\b\b%d", i);
     printf("\r");
     servo(HEAD_SERVO,i);
   /*If you connect the head servo to Servo_O2 connector this statement drives it.*/
     servo(1,i); 
   }
 
  while((rb=front_bumper())>BUMPER_FUZZY_ZERO) 
   {
     i -= servo_step;
     if(i<lpw) i = upw;
     printf("Servo Pulse Width is      \b\b\b\b\b%d", i);
     printf("\r");
     servo(HEAD_SERVO,i);
   /*If you connect the head servo to Servo_O2 connector this statement drives it.*/
     servo(1,i);
   }

  }
}
