/************************************************************************
 * Title        xserv2tk.c                                	                
 * Programmer	Keith L. Doty	        				
 * Date         July 28, 1998      	                                
 * Version	1			                		
 *								        
 * Description
 *
 *   Press and hold the rear bumper down and TALRIK's Head servo rotates
 *   in one direction. Press and hold the front bumper down and the Head
 *   rotates in the other direction. The PWM pulse width (1000<PW<5000)
 *   is output to the terminal. By momentarily pressing the bumpers you can
 *   step the PWM pulse width by a fixed number of processor cycle increments
 *   in either direction.

 * NOTE: SOME SERVOS HAVE INVERTED CONTROL AND WILL MOVE IN THE OPPOSITE
         DIRECTION. YOU CAN CORRECT FOR THIS IN THE SOFTWARE.

 *								
 * Use Hyperterm with the following settings:                           
 *   									
 *      COM1, 9600 Baud, 8 bits, No Parity, 1 Stop bit, No Flow         
 *      of Control, VT100 Terminal, WrapLines.				
 *									
 ************************************************************************/
 
/**************************** Includes **********************************/

#include <tkbase.h>
#include <stdio.h>

/************************ End of includes *******************************/


/*************************** Constants **********************************/

#define HEAD_SERVO 0 /*This is Servo_01 connector on MRSX011 board*/
#define BUMPER_FUZZY_ZERO 12 /* Noise immunity for bumper readings */
#define LPW 1000
#define UPW 5000


/************************ End of Constants ******************************/

void main(void)
/****************************** Main ***********************************/
{
int i, rb;
unsigned int servo_step;

/* VT100 clear screen */ 
  char clear[]= "\x1b\x5B\x32\x4A\x04"; 

/* VT100 position cursor at (x,y) = (3,12) command is "\x1b[3;12H"*/
  char place[]= "\x1b[1;1H";	/*Home*/	

  init_analog();
  init_motortk();
  init_clocktk();
  init_serial();
  init_servos();

  printf("%s", clear);  
  printf("%s", place);  
  
  printf("\tTitle\t\txserv2tk.c\n"
  "\tProgrammer\tKeith L. Doty\n"
  "\tDate\t\tJuly 28, 1998\n"
  "\tVersion\t\t1\n\n");

  printf("Press anywhere on the front bumper. TALRIK will turn his head in that direction.\n");

while(1)
  {

    rb=front_bumper();

  /* Move TALRIK Servo to face bump contact point */
  
     if((rb>124)&&(rb<130)) servo(HEAD_SERVO,1400);
     if((rb>148)&&(rb<154)) servo(HEAD_SERVO,1725);
     if((rb>78)&&(rb<84)) servo(HEAD_SERVO,2050);
     if((rb>100)&&(rb<106)) servo(HEAD_SERVO,2375);
     if((rb>42)&&(rb<48)) servo(HEAD_SERVO,2700);
     if((rb>58)&&(rb<64)) servo(HEAD_SERVO,3025);
     if((rb>20)&&(rb<26)) servo(HEAD_SERVO,3350);
     if((rb>33)&&(rb<39)) servo(HEAD_SERVO,3675);
     if((rb>13)&&(rb<19)) servo(HEAD_SERVO,4000);



 
   /*Wait for bumper to clear*/
     while((rb=front_bumper())>BUMPER_FUZZY_ZERO);
     wait(100);
   }


}
